pub struct DeserializeError<'a> {
pub(crate) errors: VecDeque<(&'a [u8], String)>,
}Fields
errors: VecDeque<(&'a [u8], String)>Trait Implementations
Sourceimpl<'a> Clone for DeserializeError<'a>
impl<'a> Clone for DeserializeError<'a>
Sourcefn clone(&self) -> DeserializeError<'a>
fn clone(&self) -> DeserializeError<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> ContextError<&'a [u8]> for DeserializeError<'a>
impl<'a> ContextError<&'a [u8]> for DeserializeError<'a>
Sourcefn add_context(input: &'a [u8], ctx: &'static str, other: Self) -> Self
fn add_context(input: &'a [u8], ctx: &'static str, other: Self) -> Self
Creates a new error from an input position, a static string and an existing error.
This is used mainly in the [context] combinator, to add user friendly information
to errors when backtracking through a parse tree
Sourceimpl<'a> Debug for DeserializeError<'a>
impl<'a> Debug for DeserializeError<'a>
Sourceimpl<'a> Display for DeserializeError<'a>
impl<'a> Display for DeserializeError<'a>
Sourceimpl<'a> Error for DeserializeError<'a>
impl<'a> Error for DeserializeError<'a>
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl<'a> ParseError<&'a [u8]> for DeserializeError<'a>
impl<'a> ParseError<&'a [u8]> for DeserializeError<'a>
Sourcefn append(input: &'a [u8], kind: ErrorKind, other: Self) -> Self
fn append(input: &'a [u8], kind: ErrorKind, other: Self) -> Self
Combines an existing error with a new one created from the input
position and an [ErrorKind]. This is useful when backtracking
through a parse tree, accumulating error context on the way
Sourcefn from_error_kind(input: &'a [u8], kind: ErrorKind) -> Self
fn from_error_kind(input: &'a [u8], kind: ErrorKind) -> Self
Creates an error from the input position and an [ErrorKind]